@@ -49,12 +49,15 @@ class RestlessCriteria(BaseCriteria):
 
     def all(self):
         resp = self.request()
-        return [self.resource.get_from(o) for o in resp['objects']]
+        return [self.resource.get_from(o) for o in resp]
     
     def one(self):
         self._single = True
-        resp = self.request()
-        if not resp:
+        try:
+            resp = self.request()
+            if not resp:
+                raise ObjectNotFound()
+        except IntegrityError:
             raise ObjectNotFound()
         
         if 'headers' in resp:
@@ -76,4 +79,10 @@ class RestlessModel(BaseModel):
 
     criteria_class = RestlessCriteria
     
-    
\ No newline at end of file
+    @classmethod
+    def request(cls, method, url, params=None, headers=None, data=None):
+        resp = BaseModel.request(method, url, params=params, headers=headers, data=data)
+        if 'objects' in resp:
+            return resp['objects']
+        else:
+            return resp
